#include <iostream>
#include <type_traits>

template <typename T, size_t Size>
class FixedBuffer {
    static_assert(Size > 0, "Buffer size must be greater than zero");
    static_assert(std::is_trivially_copyable<T>::value, 
                  "T must be trivially copyable for FixedBuffer");

    T buffer[Size];

public:
    void fill(const T& value) {
        for (size_t i = 0; i < Size; ++i) {
            buffer[i] = value;
        }
    }

    void print() const {
        for (size_t i = 0; i < Size; ++i) {
            std::cout << buffer[i] << " ";
        }
        std::cout << std::endl;
    }
};

int main() {
    FixedBuffer<int, 5> intBuffer;
    intBuffer.fill(42);
    intBuffer.print();

    FixedBuffer<double, 3> doubleBuffer;
    doubleBuffer.fill(3.14);
    doubleBuffer.print();

    // Uncommenting the next line would result in a compile-time error
    // FixedBuffer<int, 0> zeroSizeBuffer;

    return 0;
}
